-- Puffin: A Tojaso FowlPlay Project
-- Adapter component for hiding Blizzard unit frames

local Adapter_HideBlizzard = {}

local frames = {
	PlayerFrame = false, TargetFrame = true, FocusFrame = true, ComboFrame = true,
	PartyMemberFrame1 = true, PartyMemberFrame2 = true, PartyMemberFrame3 = true, PartyMemberFrame4 = true,
	CompactPartyFrame = { "PARTY_MEMBERS_CHANGED", "RAID_ROSTER_UPDATE" },
	CompactRaidFrameManager = { "PLAYER_ENTERING_WORLD", "RAID_ROSTER_UPDATE" },
	RuneFrame = true, BuffFrame = true, TemporaryEnchantFrame = false, ConsolidatedBuffs = false,
	-- PlayerPowerBarAlt = true, -- don't hide PlayerPowerBarAlt by default!
}

-- Hide full set of Blizzard frames
local function HideBlizzard()
	if InCombatLockdown() then return end
	for name, option in pairs(frames) do
		local frame = _G[name]
		if frame then
			if option == true then frame:UnregisterAllEvents() end
			if type(option) == "table" then for _, event in pairs(option) do frame:UnregisterEvent(event) end end
			frame:Hide()
		end
	end
end

-- Hide Blizzard raid frames (based on ShadowedUnitFrames implementation)
local function HideRaid()
	CompactRaidFrameManager:UnregisterAllEvents()
	if (not InCombatLockdown()) then CompactRaidFrameManager:Hide() end
	local shown = CompactRaidFrameManager_GetSetting("IsShown")
	if (shown and shown ~= "0") then CompactRaidFrameManager_SetSetting("IsShown", "0") end
end

-- When starting, hide the standard Blizzard frames and set up to hide raid frames when they reappear
function Adapter_HideBlizzard.OnEnable()
	HideBlizzard()
	hooksecurefunc("CompactRaidFrameManager_UpdateShown", function() HideRaid() end)
	HideRaid()
end

Puffin.RegisterComponent("Adapter_HideBlizzard", Adapter_HideBlizzard, "ADAPTER", 3)

Puffin.RegisterCallback("PARTY_CONVERTED_TO_RAID", HideBlizzard)
Puffin.RegisterCallback("PARTY_MEMBERS_CHANGED", HideBlizzard)
Puffin.RegisterCallback("RAID_ROSTER_UPDATE", HideBlizzard)
Puffin.RegisterCallback("PLAYER_ENTERING_WORLD", HideBlizzard)
Puffin.RegisterCallback("PLAYER_REGEN_ENABLED", HideBlizzard)
